musicscore
==========
Tested with python 3.9, 3.10 and 3.11

**musicscore** is a python library for generating musicxml data in an intuitive and easy but nevertheless comprehensive way. The generated
files can be imported in several music notation programs and be processed further if necessary. The preferred software is Finale which
seems at the moment to have the best implementation of musicxml format files and supports version 4.0.


For documentation see: `<https://musicscore.readthedocs.io>`_

The project can be found on GitHub under: `<https://github.com/alexgorji/musicscore>`_

**musicscore** can be installed via pip:

.. code-block:: console

    (.venv) $ pip install musicscore


**musicxml** can also be found in a separate repository under: `<https://github.com/alexgorji/musicxml>` and be installed via pip:

.. code-block:: console

    (.venv) $ pip install musicxml
